from numpy import *
import sys
import subprocess as sp
#Try to look for coregrowthdir
coregrowthdir = sp.Popen(['echo $COREGROWTHPATH'], stdout=sp.PIPE, shell=True).communicate()[0].strip()
sys.path.append(coregrowthdir+'/src/')
import core80 as core
import rout80 as rout
import globalvars80 as g


#Put the initial fragment size and the minimum fragment size at 1cm
#Which ensures a constant sF
g.sFini = 1e0
g.s_min = g.sFini#Assures no fragmntation

#Slightly enhance the surface density over the MMSN so that it
#corresponds to the situation in Chambers (2006)
g.fsig = 2.65
g.a0 = 5*g.au

#Check if we have the right surface density
[sig_ini] = rout.mmsn(['Sig_d'],a=g.a0/g.au,fsigd=g.fsigd,fsig=g.fsig) 
print sig_ini

#The parameter to write out
sQarr = ['Time', 'Mc', 'sP', 'sigP', 'sF', 'sigF']

#Switch values that are fixed
g.doOL=True
g.doND=False
g.doPG=False
g.doRD=False
g.doTD=False
g.doTS=False

#Switch values corresponding to 1st run
#Save output in data directory
g.doAE=False
g.doFR=False
g.doER = False
core.main(fmode='eq', fn_outputtable='Data/data-6a.dat')

#Switch values corresponding to 2nd run
g.doAE=True
g.doFR=False
g.doER = False
core.main(fmode='eq', fn_outputtable='Data/data-6b.dat')

#Switch values corresponding to 3rd run
g.doAE = False
g.doFR = True
g.doER = False
core.main(fmode='eq', fn_outputtable='Data/data-6c.dat')

#Switch values corresponding to 4th run
g.doAE = False
g.doFR = True
g.doER = True
core.main(fmode='eq', fn_outputtable='Data/data-6d.dat')


print('|====================================================')
print('|')
print('| Now trying to plot data. This may or may not work  ')
print('| depending on your matplotlib availibility/settings ')
print('|')
print('|====================================================')
import pylab as pl

fg0 = pl.figure()
ax0 = fg0.add_subplot(111)

fg1 = pl.figure()
ax1 = fg1.add_subplot(111)

data = rout.readData(sQarr, fname='Data/data-6a.dat')
[Time, Mc, sP, sigP, sF, sigF] = [data[:,i] for i in range(len(sQarr))]
ax0.loglog(Time/g.yr, Mc/g.Mearth, 'k-')
ax1.loglog(Time/g.yr, sigP, 'k--')

data = rout.readData(sQarr, fname='Data/data-6b.dat')
[Time, Mc, sP, sigP, sF, sigF] = [data[:,i] for i in range(len(sQarr))]
ax0.loglog(Time/g.yr, Mc/g.Mearth, '0.6')
ax1.loglog(Time/g.yr, sigP, '0.6', ls='--')

data = rout.readData(sQarr, fname='Data/data-6c.dat')
[Time, Mc, sP, sigP, sF, sigF] = [data[:,i] for i in range(len(sQarr))]
ax0.loglog(Time/g.yr, Mc/g.Mearth, 'b')
ax1.loglog(Time/g.yr, sigP, 'b')
ax1.loglog(Time/g.yr, sigF, 'b--')

data = rout.readData(sQarr, fname='Data/data-6d.dat')
[Time, Mc, sP, sigP, sF, sigF] = [data[:,i] for i in range(len(sQarr))]
ax0.loglog(Time/g.yr, Mc/g.Mearth, 'r')
ax1.loglog(Time/g.yr, sigP, 'r')
ax1.loglog(Time/g.yr, sigF, 'r--')


ax0.legend(['(default)','(def.)+AE', '(def.)+FR','(def.)+FR,+ER}'], loc=2)

ax0.set_xlabel('Time [yr]')
ax0.set_ylabel('Embryo mass $M_E$ [$M_\\oplus$]')
ax0.set_xlim(1e3,1e7)
ax0.set_ylim(1e-6,50)


ax1.set_xlabel('Time [yr]')
ax1.set_ylabel('Surface density $\\Sigma_k$ [g cm$^{-2}$]')
ax1.set_xlim(1e3,1e7)
ax1.set_ylim(sig_ini/1e5, 2*sig_ini)

fg0.savefig('fig6a.eps')
fg1.savefig('fig6b.eps')
pl.close()
