from numpy import *
import sys
import subprocess as sp
#Try to look for coregrowthdir
coregrowthdir = sp.Popen(['echo $COREGROWTHPATH'], stdout=sp.PIPE, shell=True).communicate()[0].strip()
sys.path.append(coregrowthdir+'/src/')
import globalvars80 as g
import core80 as core
import rout80 as rout

g.fsig = 3.0
g.a0   = 5.0*g.au

def load_pars(fname):
  data = rout.readData(sQarr, fname=fname)
  [Time, Mc, sigP, sigF, sP, sF, ehP] = [data[:,k] for k in range(len(sQarr))]
  return [Time, Mc]

def load_defaults():
  #default switches like in the parameter study
  g.doAE=False
  g.doND=False
  g.doFR=True
  g.doER=True
  g.doRD=True
  g.doPG=True
  g.doTD=False
  g.doTS=False
  g.alSS = 1e-4
  g.vhw = 54e2
  g.mparfile='ice'
  g.s_min = 0.1

load_defaults()
core.main(fn_outputtable='Data/table9a1.dat')
g.doTD=True
g.doTS=True
core.main(fn_outputtable='Data/table9a2.dat')
g.alSS = 0.001
core.main(fn_outputtable='Data/table9a3.dat')
g.alSS = 0.01
core.main(fn_outputtable='Data/table9a4.dat')


load_defaults()
core.main(fn_outputtable='Data/table9b1.dat')
g.mparfile='rubble'
g.s_min = 0.1
core.main(fn_outputtable='Data/table9b2.dat')
g.doND=True
g.doAE=True
core.main(fn_outputtable='Data/table9b3.dat')
g.doTD=True
core.main(fn_outputtable='Data/table9b4.dat')

load_defaults()
core.main(fn_outputtable='Data/table9c1.dat')
g.vhw=10e2
core.main(fn_outputtable='Data/table9c2.dat')
g.vhw= 2e2
core.main(fn_outputtable='Data/table9c3.dat')
g.doAE=True
core.main(fn_outputtable='Data/table9c4.dat')


print('|====================================================')
print('|')
print('| Now trying to plot data. This may or may not work  ')
print('| depending on your matplotlib availibility/settings ')
print('|')
print('|====================================================')
import pylab as pl

fg = pl.figure(figsize=(12,4))
ax1 = fg.add_subplot(131)
ax2 = fg.add_subplot(132)
ax3 = fg.add_subplot(133)
sQarr = ['Time', 'Mc', 'sigP', 'sigF', 'sP', 'sF', 'ehP']

axs = [ax1, ax2, ax3]
N = len(axs)

[Time, Mc] = load_pars('Data/table9a1.dat')
ax1.loglog(Time/g.yr, Mc/g.Mearth, '-', c='0.7', lw=3.0)
[Time, Mc] = load_pars('Data/table9a2.dat')
ax1.loglog(Time/g.yr, Mc/g.Mearth, 'k-')
[Time, Mc] = load_pars('Data/table9a3.dat')
ax1.loglog(Time/g.yr, Mc/g.Mearth, 'k--')
[Time, Mc] = load_pars('Data/table9a4.dat')
ax1.loglog(Time/g.yr, Mc/g.Mearth, 'k:')


[Time, Mc] = load_pars('Data/table9b1.dat')
ax2.loglog(Time/g.yr, Mc/g.Mearth, '-', c='0.7', lw=3.0)
[Time, Mc] = load_pars('Data/table9b2.dat')
ax2.loglog(Time/g.yr, Mc/g.Mearth, 'k-')
[Time, Mc] = load_pars('Data/table9b3.dat')
ax2.loglog(Time/g.yr, Mc/g.Mearth, 'k--')
[Time, Mc] = load_pars('Data/table9b4.dat')
ax2.loglog(Time/g.yr, Mc/g.Mearth, 'k:')

[Time, Mc] = load_pars('Data/table9c1.dat')
ax3.loglog(Time/g.yr, Mc/g.Mearth, '-', c='0.7', lw=3.0)
[Time, Mc] = load_pars('Data/table9c2.dat')
ax3.loglog(Time/g.yr, Mc/g.Mearth, 'k-')
[Time, Mc] = load_pars('Data/table9c3.dat')
ax3.loglog(Time/g.yr, Mc/g.Mearth, 'k--')
[Time, Mc] = load_pars('Data/table9c4.dat')
ax3.loglog(Time/g.yr, Mc/g.Mearth, 'k:')

for i in range(N):
  ax = axs[i]
  ax.set_xlim(2.1e4, 1e7)
  ax.set_ylim(1.1e-3, 5e1)

ax1.text(0.2, 0.92, 'Turbulence variation', fontsize=16, transform=ax1.transAxes)
ax2.text(0.2, 0.92, 'Material variation',  fontsize=16,transform=ax2.transAxes)
ax3.text(0.2, 0.92, 'Headwind variation',  fontsize=16,transform=ax3.transAxes)

ax1.legend(['Default', '+TS,TD', '$\\alpha_\\mathrm{ss}=10^{-3}$'], loc=(0.05, 0.6), frameon=False)
ax2.legend(['Default', 'Rubble', '+AE,ND', '+TS,TD'], loc=4, frameon=False)
ax3.legend(['Default', '$v_\\mathrm{hw}=10\ \\mathrm{m\ s^{-1}}$', '$v_\\mathrm{hw}=2\ \\mathrm{m\ s^{-1}}$', '+AE'], loc=4, frameon=False)

ax2.set_yticklabels([])
ax3.set_yticklabels([])
ax2.set_xlabel('Time [yr]')
ax1.set_ylabel('Embryo mass [Earth mass]')

fg.savefig('fig9.eps')
pl.close()
